@@ -18,13 +18,13 @@ wiki_call <- function(URL, ...){
   response <- GET(URL, ...)
   
   #Check the validity of the response from a server POV
-  ConnectionErrorHandler(response)
+  handle_connection_errors(response)
   
   #Parse it
   parsed_response <- wiki_parse(response = response)
   
   #Check for API errors
-  APIErrorHandler(parsed_response)
+  handle_API_errors(parsed_response)
   
   #Return
   return(parsed_response)
